import { Command } from 'ckeditor5/src/core';

export default class InsertDrupalLayoutCommand extends Command {

  refresh() {
    const model = this.editor.model;
    const selection = model.document.selection;
    const allowedIn = model.schema.findAllowedParent(selection.getFirstPosition(), 'drupalLayout');

    this.isEnabled = allowedIn !== null;
  }

  execute(layoutTemplate) {
    this.editor.model.change(writer => {
      this.editor.model.insertObject(createDrupalLayout(layoutTemplate, writer));
    });
  }

}

function createDrupalLayout(layoutTemplate, writer) {
  const layoutTemplateDom = new DOMParser().parseFromString(layoutTemplate, 'text/html');
  const drupalLayout = writer.createElement('drupalLayout');

  const layoutTemplateRows = layoutTemplateDom.body.childNodes;
  layoutTemplateRows.forEach(row => {
    // Skip text nodes.
    if (Node.TEXT_NODE === row.nodeType) {
      return;
    }

    const rowAttributes = [];
    for (let i = 0; i < row.attributes.length; i++) {
      rowAttributes.push({ name: row.attributes.item(i).name, value: row.attributes.item(i).value });
    };
    const drupalLayoutRow = writer.createElement('drupalLayoutRow', { tagName: row.tagName.toLowerCase(), tagAttributes: JSON.stringify(rowAttributes) });
    writer.append(drupalLayoutRow, drupalLayout);

    const layoutTemplateRowColumns = row.childNodes;
    layoutTemplateRowColumns.forEach(column => {
      // Skip text nodes.
      if (Node.TEXT_NODE === column.nodeType) {
        return;
      }

      const columnAttributes = [];
      for (let j = 0; j < column.attributes.length; j++) {
        columnAttributes.push({ name: column.attributes.item(j).name, value: column.attributes.item(j).value });
      };
      const drupalLayoutColumn = writer.createElement('drupalLayoutColumn', { tagName: column.tagName.toLowerCase(), tagAttributes: JSON.stringify(columnAttributes) });
      writer.append(drupalLayoutColumn, drupalLayoutRow);

      // We need at least an empty paragraph for the column to be
      // editable.
      // @see https://github.com/ckeditor/ckeditor5/issues/1464.
      writer.appendElement('paragraph', drupalLayoutColumn);
    });
  });

  return drupalLayout;
}
