import icon from '../../../../icons/layouts.svg';
import { ButtonView, addToolbarToDropdown, createDropdown } from 'ckeditor5/src/ui';
import { Plugin } from 'ckeditor5/src/core';

export default class InsertDrupalLayoutUi extends Plugin {
  init() {
    const editor = this.editor;
    const config = editor.config.get('drupalLayouts');

    editor.ui.componentFactory.add( 'insertDrupalLayout', (locale) => {
      const button = createDropdown(locale);

      // Create the toolbar item.
      button.buttonView.set({
        label: Drupal.t('Insert layout'),
        icon,
        tooltip: true
      });

      // Create the dropdown panel content.
      const buttonsCreator = () => {
        const buttons = [];

        config.layouts.forEach((layout) => {
          const button = new ButtonView(editor.locale);
          button.set({
            label: layout.label,
            withText: true,
          });

          this.listenTo(button, 'execute', () => {
            editor.execute('insertDrupalLayout', layout.template);
          });

          buttons.push(button);
        });

        return buttons;
      };

      addToolbarToDropdown(button, buttonsCreator, { isVertical: true });

      return button;
    });
  }

}
